@@ -1,3 +1,6 @@
+// need this for ructe
+#![allow(clippy::needless_borrow)]
+
 use actix_web::{
     http::{
         header::{CacheControl, CacheDirective, ContentType, LastModified, LOCATION},
@@ -92,7 +95,6 @@ pub struct State {
     upstream: Url,
     scope: String,
     store: Store,
-    db: Db,
     startup: SystemTime,
 }
 
@@ -208,7 +210,6 @@ pub fn state(config: Config, scope: &str, db: Db) -> Result<State, sled::Error>
         upstream: config.upstream,
         scope: scope.to_string(),
         store: Store::new(&db)?,
-        db,
         startup: SystemTime::now(),
     })
 }
@@ -359,7 +360,7 @@ struct Error {
 
 impl std::fmt::Display for Error {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(f, "{}\n", self.kind)?;
+        writeln!(f, "{}", self.kind)?;
         std::fmt::Display::fmt(&self.context, f)
     }
 }
